@@ -12,15 +12,18 @@ import os
 import time
 import logging
 
+from copy import deepcopy
+
 from rayvision_sync.manage import RayvisionManageTask
 # Import local modules
 from rayvision_sync.transfer import RayvisionTransfer
-from rayvision_sync.exception import DownloadFailed
+from rayvision_sync.exception import DownloadFailed, UnsupportedEngineType
 from rayvision_sync.utils import create_transfer_params
 from rayvision_sync.utils import run_cmd
 from rayvision_sync.utils import str2unicode
 from rayvision_log import init_logger
 from rayvision_sync.constants import PACKAGE_NAME
+from rayvision_sync.rayvision_raysync.transfer_raysync import RayvisionTransferRaysync
 
 class RayvisionDownload(object):
     """Downloader.
@@ -65,6 +68,9 @@ class RayvisionDownload(object):
             init_logger(PACKAGE_NAME, log_folder, log_name)
             self.logger = logging.getLogger(__name__)
             self.logger.setLevel(level=log_level.upper())
+        self.raysync_engine = RayvisionTransferRaysync(self.trans.user_id, self.api.user_info.get("user_name"),
+                                                       self.api.query.get_raysync_user_key().get('raySyncUserKey'),
+                                                       self.trans.platform, self.logger)
 
     def _download_log(self, task_id_list, local_path):
         """Download log Settings.
@@ -132,7 +138,7 @@ class RayvisionDownload(object):
             server_path (str or list): The user customizes the file structure to be downloaded from
                 the output server, and all file structures are downloaded by default,
                 example: "18164087_test/l_layer".
-            engine_type (str, optional): set engine type, support "aspera" and "raysync", Default "aspera".
+            engine_type (str, optional): set engine type, support "aspera" and "raysyncweb", Default "aspera".
             server_ip (str, optional): transmit server host,
                 if not set, it is obtained from the default transport profile.
             server_port (str, optional): transmit server port,
@@ -183,7 +189,7 @@ class RayvisionDownload(object):
             local_path (str): Download file locally save path,
                 default Window system is "USERPROFILE" environment variable address splicing "renderfarm_sdk",
                 Linux system is "HOME" environment variable address splicing "renderfarm_sdk".
-            engine_type (str, optional): set engine type, support "aspera" and "raysync", Default "aspera".
+            engine_type (str, optional): set engine type, support "aspera" and "raysyncweb", Default "aspera".
             server_ip (str, optional): transmit server host,
                 if not set, it is obtained from the default transport profile.
             server_port (str, optional): transmit server port,
@@ -229,7 +235,7 @@ class RayvisionDownload(object):
         while True:
             if task_id_list:
                 time.sleep(float(sleep_time))
-                task_id_list_copy = task_id_list.copy()
+                task_id_list_copy = deepcopy(task_id_list)
                 for task_id in task_id_list:
                     download_flag = True
                     is_task_end = self.manage_task.is_task_end(task_id)
@@ -247,7 +253,7 @@ class RayvisionDownload(object):
                     if is_task_end is True:
                         self.logger.info('The tasks end: %s', task_id)
                         task_id_list_copy.remove(task_id)
-                task_id_list = task_id_list_copy.copy()
+                task_id_list = deepcopy(task_id_list_copy)
             else:
                 break
         if download_failed_list:
@@ -278,7 +284,7 @@ class RayvisionDownload(object):
             local_path (str): Download file locally save path,
                 default Window system is "USERPROFILE" environment variable address splicing "renderfarm_sdk",
                 Linux system is "HOME" environment variable address splicing "renderfarm_sdk".
-            engine_type (str, optional): set engine type, support "aspera" and "raysync", Default "aspera".
+            engine_type (str, optional): set engine type, support "aspera" and "raysyncweb", Default "aspera".
             server_ip (str, optional): transmit server host,
                 if not set, it is obtained from the default transport profile.
             server_port (str, optional): transmit server port,
@@ -336,7 +342,7 @@ class RayvisionDownload(object):
             server_path (str / list): The user customizes the file structure to be downloaded from
                 the output server, and all file structures are downloaded by default,
                 example: "18164087_test/l_layer".
-            engine_type (str, optional): set engine type, support "aspera" and "raysync", Default "aspera".
+            engine_type (str, optional): set engine type, support "aspera" and "raysyncweb", Default "aspera".
             server_ip (str, optional): transmit server host,
                 if not set, it is obtained from the default transport profile.
             server_port (str, optional): transmit server port,
@@ -369,9 +375,26 @@ class RayvisionDownload(object):
             cmd_params = [transmit_type, local_path, output_file_name,
                           max_speed, download_filename_format, 'output_bid']
 
-            cmd = self.trans.create_cmd(cmd_params, engine_type=engine_type,
-                                        server_ip=server_ip, server_port=server_port,
-                                        network_mode=network_mode)
-            tranfer_code = run_cmd(cmd, print_log=print_log, logger=self.logger)
+            if engine_type == "aspera":
+                cmd = self.trans.create_cmd(cmd_params, engine_type=engine_type,
+                                            server_ip=server_ip, server_port=server_port,
+                                            network_mode=network_mode)
+                tranfer_code = run_cmd(cmd, print_log=print_log, logger=self.logger)
+            elif engine_type == "raysyncweb":
+                tranfer_code = self.raysync_engine.start_transfer(**{
+                    "server_ip": server_ip if server_ip else self.trans.transport_info['raysyncweb']['server_ip'],
+                    "server_port": server_port if server_port else self.trans.transport_info['raysyncweb']['server_port'],
+                    "local_path": local_path,
+                    "server_path": output_file_name,
+                    "storage_id": self.trans.output_bid,
+                    "task_type" : "download",
+                    "task_id": task_id_list[0],
+                    "max_speed": max_speed
+                })
+            else:
+                msg = "{} is not a supported transport engine, " \
+                      "currently only support 'aspera' and 'raysyncweb'".format(engine_type)
+                raise UnsupportedEngineType(msg)
+
             if tranfer_code != 0:
                 raise DownloadFailed('%s Download failed' % output_file_name)
\ No newline at end of file
