@@ -12,15 +12,18 @@ import subprocess
 from concurrent.futures import ThreadPoolExecutor
 
 # Import local modules
+from rayvision_sync.rayvision_raysync.transfer_raysync import RayvisionTransferRaysync
 from rayvision_sync import RayvisionTransfer
 from rayvision_sync.constants import TRANSFER_LOG, RENDERFARM_SDK, WINDOWS_LOCAL_ENV, LINUX_LOCAL_ENV, RAYVISION_DB
-from rayvision_sync.exception import RayvisionError, UnsupportedDatabaseError
+from rayvision_sync.exception import RayvisionError, UnsupportedDatabaseError, UnsupportedEngineType
 from rayvision_sync.utils import create_transfer_params, get_share_info
 from rayvision_sync.utils import read_ini_config
 from rayvision_sync.utils import run_cmd
 from rayvision_sync.utils import str2unicode
 from rayvision_sync.utils import upload_retry
-from rayvision_sync.constants import PACKAGE_NAME
+from rayvision_api.utils import append_to_upload
+from rayvision_sync.rayvision_raysync.utils import upload_list_convert_list
+from rayvision_sync.constants import PACKAGE_NAME, ENGINE_TYPE
 from rayvision_log import init_logger
 
 class RayvisionUpload(object):
@@ -68,6 +71,9 @@ class RayvisionUpload(object):
         params["internet_provider"] = internet_provider
         self.api = api
         self.trans = RayvisionTransfer(api, **params)
+        self.raysync_engine = RayvisionTransferRaysync(self.trans.user_id, self.api.user_info.get("user_name"),
+                                                       self.api.query.get_raysync_user_key().get('raySyncUserKey'),
+                                                       self.trans.platform, self.logger)
 
         # load db config ini
         self.transfer_log_path, self.redis_config, self.sqlite_config, self.database_config = \
@@ -180,7 +186,7 @@ class RayvisionUpload(object):
             transmit_type (str): transmit type:
                 1. upload_json: upload from json file,in this type, next remote will not used.
                 2. upload_list: upload from file list.
-            engine_type (str, optional): set engine type, support "aspera" and "raysync", Default "aspera".
+            engine_type (str, optional): set engine type, support "aspera" and "raysyncweb", Default "aspera".
             server_ip (str, optional): transmit server host,
                 if not set, it is obtained from the default transport profile.
             server_port (str, optional): transmit server port,
@@ -225,7 +231,7 @@ class RayvisionUpload(object):
             config_file_list (list): Configuration file path list.
             max_speed (str): Maximum transmission speed, default value
                 is 1048576 KB/S.
-            engine_type (str, optional): set engine type, support "aspera" and "raysync", Default "aspera".
+            engine_type (str, optional): set engine type, support "aspera" and "raysyncweb", Default "aspera".
             server_ip (str, optional): transmit server host,
                 if not set, it is obtained from the default transport profile.
             server_port (str, optional): transmit server port,
@@ -253,12 +259,30 @@ class RayvisionUpload(object):
                 continue
             cmd_params = [transmit_type, local_path, server_path, max_speed,
                           'false', 'config_bid']
-            cmd = self.trans.create_cmd(cmd_params, engine_type=engine_type, server_ip=server_ip,
-                                        server_port=server_port, network_mode=network_mode)
 
             times = 0
             while True:
-                result = run_cmd(cmd, flag=True, logger=self.logger)
+                if engine_type == "aspera":
+                    cmd = self.trans.create_cmd(cmd_params, engine_type=engine_type, server_ip=server_ip,
+                                                server_port=server_port, network_mode=network_mode)
+                    result = run_cmd(cmd, flag=True, logger=self.logger)
+                elif engine_type == "raysyncweb":
+                    paramDict = {
+                        "server_ip": server_ip if server_ip else self.trans.transport_info[engine_type]['server_ip'],
+                        "server_port": server_port if server_port else self.trans.transport_info[engine_type]['server_port'],
+                        "local_path": local_path,
+                        "server_path": server_path,
+                        "storage_id": self.trans.config_bid,
+                        "task_type": "upload",
+                        "file_type": "json",
+                        "task_id": task_id,
+                        "max_speed": max_speed
+                    }
+                    result = self.raysync_engine.start_transfer(**paramDict)
+                else:
+                    msg = "{} is not a supported transport engine, " \
+                      "currently only support 'aspera' and 'raysyncweb'".format(engine_type)
+                    raise UnsupportedEngineType(msg)
                 if result:
                     if times == 9:
                         raise RayvisionError(20004, "%s upload failed" %
@@ -280,7 +304,7 @@ class RayvisionUpload(object):
             max_speed (str): Maximum transmission speed, default value
                 is 1048576 KB/S.
             is_db (bool): Whether to produce local database record upload file.
-            engine_type (str): Transport engine type, supports "aspera" and "raysync".
+            engine_type (str): Transport engine type, supports "aspera" and "raysyncweb".
             server_ip (str): Transport server IP.
             server_port (str): Transport server port.
             transmit_type (str): transmit type:
@@ -305,11 +329,30 @@ class RayvisionUpload(object):
         else:
             db_ini_path = None
         main_input_bid, main_user_id = get_share_info(self.api)
-        cmd = self.trans.create_cmd(cmd_params, db_ini_path, engine_type, server_ip, server_port,
-                                    main_user_id=main_user_id, main_input_bid=main_input_bid,
-                                    network_mode=network_mode)
-
-        return run_cmd(cmd, flag=True, logger=self.logger, is_record=is_record, redis_flag=redis_flag, redis_obj=redis_obj)
+        if engine_type == "aspera":
+            cmd = self.trans.create_cmd(cmd_params, db_ini_path, engine_type, server_ip, server_port,
+                                        main_user_id=main_user_id, main_input_bid=main_input_bid,
+                                        network_mode=network_mode)
+            result = run_cmd(cmd, flag=True, logger=self.logger, is_record=is_record, redis_flag=redis_flag, redis_obj=redis_obj)
+        elif engine_type == "raysyncweb":
+            if transmit_type == "upload_list":
+                upload_list, upload_json_path = upload_list_convert_list(upload_json_path)
+                append_to_upload(upload_list, upload_json_path)
+            paramDict = {
+                "server_ip": server_ip if server_ip else self.trans.transport_info[engine_type]['server_ip'],
+                "server_port": server_port if server_port else self.trans.transport_info[engine_type]['server_port'],
+                "local_path": upload_json_path,
+                "server_path": "",
+                "storage_id": self.trans.input_bid,
+                "task_type": "upload-list",
+                "max_speed": max_speed
+            }
+            result = self.raysync_engine.start_transfer(**paramDict)
+        else:
+            msg = "{} is not a supported transport engine, " \
+                  "currently only support 'aspera' and 'raysyncweb'".format(engine_type)
+            raise UnsupportedEngineType(msg)
+        return result
 
     def load_db_config(self, db_config_path=None):
         if not bool(db_config_path) or not os.path.exists(db_config_path):
